# -*- coding: utf-8 -*-
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: saturn_bot/plugin/grpc_controller.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'saturn_bot/plugin/grpc_controller.proto\x12\x06plugin\"\x07\n\x05\x45mpty2:\n\x0eGRPCController\x12(\n\x08Shutdown\x12\r.plugin.Empty\x1a\r.plugin.EmptyBc\n\ncom.pluginB\x13GrpcControllerProtoP\x01Z\x08./plugin\xa2\x02\x03PXX\xaa\x02\x06Plugin\xca\x02\x06Plugin\xe2\x02\x12Plugin\\GPBMetadata\xea\x02\x06Pluginb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'saturn_bot.plugin.grpc_controller_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.pluginB\023GrpcControllerProtoP\001Z\010./plugin\242\002\003PXX\252\002\006Plugin\312\002\006Plugin\342\002\022Plugin\\GPBMetadata\352\002\006Plugin'
  _globals['_EMPTY']._serialized_start=51
  _globals['_EMPTY']._serialized_end=58
  _globals['_GRPCCONTROLLER']._serialized_start=60
  _globals['_GRPCCONTROLLER']._serialized_end=118
# @@protoc_insertion_point(module_scope)
