# -*- coding: utf-8 -*-
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: saturn_bot/plugin/grpc_stdio.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"saturn_bot/plugin/grpc_stdio.proto\x12\x06plugin\x1a\x1bgoogle/protobuf/empty.proto\"\x84\x01\n\tStdioData\x12\x33\n\x07\x63hannel\x18\x01 \x01(\x0e\x32\x19.plugin.StdioData.ChannelR\x07\x63hannel\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\".\n\x07\x43hannel\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06STDOUT\x10\x01\x12\n\n\x06STDERR\x10\x02\x32G\n\tGRPCStdio\x12:\n\x0bStreamStdio\x12\x16.google.protobuf.Empty\x1a\x11.plugin.StdioData0\x01\x42^\n\ncom.pluginB\x0eGrpcStdioProtoP\x01Z\x08./plugin\xa2\x02\x03PXX\xaa\x02\x06Plugin\xca\x02\x06Plugin\xe2\x02\x12Plugin\\GPBMetadata\xea\x02\x06Pluginb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'saturn_bot.plugin.grpc_stdio_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.pluginB\016GrpcStdioProtoP\001Z\010./plugin\242\002\003PXX\252\002\006Plugin\312\002\006Plugin\342\002\022Plugin\\GPBMetadata\352\002\006Plugin'
  _globals['_STDIODATA']._serialized_start=76
  _globals['_STDIODATA']._serialized_end=208
  _globals['_STDIODATA_CHANNEL']._serialized_start=162
  _globals['_STDIODATA_CHANNEL']._serialized_end=208
  _globals['_GRPCSTDIO']._serialized_start=210
  _globals['_GRPCSTDIO']._serialized_end=281
# @@protoc_insertion_point(module_scope)
