# -*- coding: utf-8 -*-
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: saturn_bot/protocol/v1/saturnbot.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&saturn_bot/protocol/v1/saturnbot.proto\x12\x0bprotocol.v1\"[\n\x15\x45xecuteActionsRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12.\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\"\xd2\x01\n\x16\x45xecuteActionsResponse\x12\x19\n\x05\x65rror\x18\x01 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x12K\n\x08run_data\x18\x04 \x03(\x0b\x32\x30.protocol.v1.ExecuteActionsResponse.RunDataEntryR\x07runData\x1a:\n\x0cRunDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_errorJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"G\n\x15\x45xecuteFiltersRequest\x12.\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\"\xe8\x01\n\x16\x45xecuteFiltersResponse\x12\x14\n\x05match\x18\x01 \x01(\x08R\x05match\x12\x19\n\x05\x65rror\x18\x02 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x12K\n\x08run_data\x18\x05 \x03(\x0b\x32\x30.protocol.v1.ExecuteFiltersResponse.RunDataEntryR\x07runData\x1a:\n\x0cRunDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_errorJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\x90\x01\n\x10GetPluginRequest\x12\x41\n\x06\x63onfig\x18\x01 \x03(\x0b\x32).protocol.v1.GetPluginRequest.ConfigEntryR\x06\x63onfig\x1a\x39\n\x0b\x43onfigEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"h\n\x11GetPluginResponse\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1a\n\x08priority\x18\x02 \x01(\x05R\x08priority\x12\x19\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"\x95\x02\n\x07\x43ontext\x12\x37\n\nrepository\x18\x01 \x01(\x0b\x32\x17.protocol.v1.RepositoryR\nrepository\x12@\n\x0cpull_request\x18\x02 \x01(\x0b\x32\x18.protocol.v1.PullRequestH\x00R\x0bpullRequest\x88\x01\x01\x12<\n\x08run_data\x18\x04 \x03(\x0b\x32!.protocol.v1.Context.RunDataEntryR\x07runData\x1a:\n\x0cRunDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0f\n\r_pull_requestJ\x04\x08\x03\x10\x04\">\n\x0bPullRequest\x12\x16\n\x06number\x18\x01 \x01(\x03R\x06number\x12\x17\n\x07web_url\x18\x02 \x01(\tR\x06webUrl\"\x8c\x01\n\nRepository\x12\x1b\n\tfull_name\x18\x01 \x01(\tR\x08\x66ullName\x12$\n\x0e\x63lone_url_http\x18\x02 \x01(\tR\x0c\x63loneUrlHttp\x12\"\n\rclone_url_ssh\x18\x03 \x01(\tR\x0b\x63loneUrlSsh\x12\x17\n\x07web_url\x18\x04 \x01(\tR\x06webUrl\"C\n\x11OnPrClosedRequest\x12.\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\"9\n\x12OnPrClosedResponse\x12\x19\n\x05\x65rror\x18\x01 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"D\n\x12OnPrCreatedRequest\x12.\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\":\n\x13OnPrCreatedResponse\x12\x19\n\x05\x65rror\x18\x01 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"C\n\x11OnPrMergedRequest\x12.\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\"9\n\x12OnPrMergedResponse\x12\x19\n\x05\x65rror\x18\x01 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error2\x8d\x04\n\rPluginService\x12[\n\x0e\x45xecuteActions\x12\".protocol.v1.ExecuteActionsRequest\x1a#.protocol.v1.ExecuteActionsResponse\"\x00\x12[\n\x0e\x45xecuteFilters\x12\".protocol.v1.ExecuteFiltersRequest\x1a#.protocol.v1.ExecuteFiltersResponse\"\x00\x12L\n\tGetPlugin\x12\x1d.protocol.v1.GetPluginRequest\x1a\x1e.protocol.v1.GetPluginResponse\"\x00\x12O\n\nOnPrClosed\x12\x1e.protocol.v1.OnPrClosedRequest\x1a\x1f.protocol.v1.OnPrClosedResponse\"\x00\x12R\n\x0bOnPrCreated\x12\x1f.protocol.v1.OnPrCreatedRequest\x1a .protocol.v1.OnPrCreatedResponse\"\x00\x12O\n\nOnPrMerged\x12\x1e.protocol.v1.OnPrMergedRequest\x1a\x1f.protocol.v1.OnPrMergedResponse\"\x00\x42n\n\x0f\x63om.protocol.v1B\x0eSaturnbotProtoP\x01\xa2\x02\x03PXX\xaa\x02\x0bProtocol.V1\xca\x02\x0bProtocol\\V1\xe2\x02\x17Protocol\\V1\\GPBMetadata\xea\x02\x0cProtocol::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'saturn_bot.protocol.v1.saturnbot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.protocol.v1B\016SaturnbotProtoP\001\242\002\003PXX\252\002\013Protocol.V1\312\002\013Protocol\\V1\342\002\027Protocol\\V1\\GPBMetadata\352\002\014Protocol::V1'
  _globals['_EXECUTEACTIONSRESPONSE_RUNDATAENTRY']._options = None
  _globals['_EXECUTEACTIONSRESPONSE_RUNDATAENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTEFILTERSRESPONSE_RUNDATAENTRY']._options = None
  _globals['_EXECUTEFILTERSRESPONSE_RUNDATAENTRY']._serialized_options = b'8\001'
  _globals['_GETPLUGINREQUEST_CONFIGENTRY']._options = None
  _globals['_GETPLUGINREQUEST_CONFIGENTRY']._serialized_options = b'8\001'
  _globals['_CONTEXT_RUNDATAENTRY']._options = None
  _globals['_CONTEXT_RUNDATAENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTEACTIONSREQUEST']._serialized_start=55
  _globals['_EXECUTEACTIONSREQUEST']._serialized_end=146
  _globals['_EXECUTEACTIONSRESPONSE']._serialized_start=149
  _globals['_EXECUTEACTIONSRESPONSE']._serialized_end=359
  _globals['_EXECUTEACTIONSRESPONSE_RUNDATAENTRY']._serialized_start=279
  _globals['_EXECUTEACTIONSRESPONSE_RUNDATAENTRY']._serialized_end=337
  _globals['_EXECUTEFILTERSREQUEST']._serialized_start=361
  _globals['_EXECUTEFILTERSREQUEST']._serialized_end=432
  _globals['_EXECUTEFILTERSRESPONSE']._serialized_start=435
  _globals['_EXECUTEFILTERSRESPONSE']._serialized_end=667
  _globals['_EXECUTEFILTERSRESPONSE_RUNDATAENTRY']._serialized_start=279
  _globals['_EXECUTEFILTERSRESPONSE_RUNDATAENTRY']._serialized_end=337
  _globals['_GETPLUGINREQUEST']._serialized_start=670
  _globals['_GETPLUGINREQUEST']._serialized_end=814
  _globals['_GETPLUGINREQUEST_CONFIGENTRY']._serialized_start=757
  _globals['_GETPLUGINREQUEST_CONFIGENTRY']._serialized_end=814
  _globals['_GETPLUGINRESPONSE']._serialized_start=816
  _globals['_GETPLUGINRESPONSE']._serialized_end=920
  _globals['_CONTEXT']._serialized_start=923
  _globals['_CONTEXT']._serialized_end=1200
  _globals['_CONTEXT_RUNDATAENTRY']._serialized_start=279
  _globals['_CONTEXT_RUNDATAENTRY']._serialized_end=337
  _globals['_PULLREQUEST']._serialized_start=1202
  _globals['_PULLREQUEST']._serialized_end=1264
  _globals['_REPOSITORY']._serialized_start=1267
  _globals['_REPOSITORY']._serialized_end=1407
  _globals['_ONPRCLOSEDREQUEST']._serialized_start=1409
  _globals['_ONPRCLOSEDREQUEST']._serialized_end=1476
  _globals['_ONPRCLOSEDRESPONSE']._serialized_start=1478
  _globals['_ONPRCLOSEDRESPONSE']._serialized_end=1535
  _globals['_ONPRCREATEDREQUEST']._serialized_start=1537
  _globals['_ONPRCREATEDREQUEST']._serialized_end=1605
  _globals['_ONPRCREATEDRESPONSE']._serialized_start=1607
  _globals['_ONPRCREATEDRESPONSE']._serialized_end=1665
  _globals['_ONPRMERGEDREQUEST']._serialized_start=1667
  _globals['_ONPRMERGEDREQUEST']._serialized_end=1734
  _globals['_ONPRMERGEDRESPONSE']._serialized_start=1736
  _globals['_ONPRMERGEDRESPONSE']._serialized_end=1793
  _globals['_PLUGINSERVICE']._serialized_start=1796
  _globals['_PLUGINSERVICE']._serialized_end=2321
# @@protoc_insertion_point(module_scope)
